@@ -1,10 +1,11 @@
 from goyabucli.anilistManager import AnilistManager
+from goyabucli.serverManager import ServerManager
 from .scraperManager import ScraperManager
 from .anilistManager import AnilistManager, MissingToken
 from .sessionManager import SessionManager, SessionItem
 from .playerManager import PlayerManager
 from .dropdown import Cursor, Highlight, interactiveTable
-from .translation import t, error, warning
+from .translation import t, error, warning, lang
 from .progress import progress
 import termtables as tt
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -21,9 +22,12 @@ class Config:
     config_dir:str
     player:str
     silent:bool
+    lang:str = lang
 
 def mainTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_range:Dict[str,Union[None,int]], always_yes:bool, default_scraper:List[str], config=Config('','','','', False)):
     manager = ScraperManager()
+    manager.scrapers = list(filter(lambda x: config.lang in x.lang, manager.scrapers))
+
     sessionmanager = SessionManager(scrapers=manager.scrapers, root=config.config_dir)
 
     selected_item = sessionmanager.select(query=default_anime_name, maxListSize=10)
@@ -182,7 +186,7 @@ def mainTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_rang
             start_pos = ep_ids.index(last_watch_pos-1)
 
             # jump to next episode if user stopped at the end of the episode of the previous session
-            if session_anime.status == 'insync':
+            if session_anime.status == 'ongoing' and session_anime.currentEpisodedEnded():
                 start_pos += 1
                 seek_time = 0
 
@@ -205,14 +209,16 @@ def mainTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_rang
             warning("    eg: anime --config")
 
     print(t('Atualizando o histórico...'))
-    # anilistManager.update_session(sessionmanager, True)
-    sessionmanager.dump(verbose=True, number_to_update=10)
 
     anime_session_item = sessionmanager.find(anime)
 
     if anime_session_item:
+        anilistManager.updateSessionItem(anime_session_item)
         anilistManager.set_watching([anime_session_item])
 
+    # anilistManager.update_session(sessionmanager, True)
+    sessionmanager.dump(verbose=True, number_to_update=10)
+
 
 
 def configTUI(config: Config, anilistManager:AnilistManager):
@@ -225,6 +231,7 @@ def configTUI(config: Config, anilistManager:AnilistManager):
             'Config directory': config.config_dir,
             'Player': config.player,
             'Silent': config.silent,
+            'Language': config.lang,
         }
         rows = [ [key, value] for key,value in  config_dict.items() ]
 
@@ -234,7 +241,8 @@ def configTUI(config: Config, anilistManager:AnilistManager):
             "cc",
             highlightRange=(0,2),
             staticHighlights=[Highlight(0, 'green' if config.token else 'fail')],
-            flexColumn=2
+            flexColumn=2,
+            maxListSize=len(config_dict)
         )
 
         if not results.selectedItem:
@@ -258,6 +266,8 @@ def configTUI(config: Config, anilistManager:AnilistManager):
             change_field('config_dir')
         elif results.selectedItem[0] == 'Player':
             change_field('player')
+        elif results.selectedItem[0] == 'Language':
+            change_field('lang')
         elif results.selectedItem[0] == 'Silent':
 
             selected = interactiveTable(
@@ -289,10 +299,12 @@ def configTUI(config: Config, anilistManager:AnilistManager):
 
 def serverTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_range:Dict[str,Union[None,int]], always_yes:bool, default_scraper:List[str], config=Config('','','','', False)):
     manager = ScraperManager()
+    manager.scrapers = list(filter(lambda x: lang in x.lang, manager.scrapers))
+
     sessionmanager = SessionManager(scrapers=manager.scrapers, root=config.config_dir)
 
 
-    selected_animes = []
+    selected_items:List[SessionItem] = []
 
     while True:
         selected_item = sessionmanager.multi_select(query=default_anime_name, maxListSize=10)
@@ -325,9 +337,12 @@ def serverTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_ra
                     print(results)
                     exit()
 
-                selected_animes.append(animes[results.selectedPos])
+                new_session_item = SessionItem(animes[results.selectedPos], 0, 0, 1, '')
+
+                selected_items.append(new_session_item)
             else:
-                selected_animes.append(animes[0])
+                new_session_item = SessionItem(animes[0], 0, 0, 1, '')
+                selected_items.append(new_session_item)
 
             selected = interactiveTable(
                 [
@@ -338,8 +353,8 @@ def serverTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_ra
                 "cl",
                 highlightRange=(0,1),
                 staticHighlights=[
-                    Highlight(0, 'green'),
-                    Highlight(1, 'fail'),
+                    Highlight(0, 'fail'),
+                    Highlight(1, 'green'),
                 ],
             )
             if not selected.selectedItem:
@@ -348,30 +363,30 @@ def serverTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_ra
             if selected.selectedItem[1] == 'Não':
                 break
         else:
-            selected_animes.extend(map(lambda x: x.anime, selected_item))
+            selected_items.extend(selected_item)
             break
 
 
 
     tt.print(
-        list(map(lambda x: [x.title], selected_animes)),
+        list(map(lambda x: [x.title], selected_items)),
         header=[t("Animes Selecionados")],
         style=tt.styles.rounded,
         alignment="c",
     )
 
 
-    for selected_anime in selected_animes:
-        session_anime = sessionmanager.find(selected_anime)
+    for selected_item in selected_items:
+        session_anime = sessionmanager.find(selected_item.anime, selected_item.anilist_id)
 
         if session_anime:
             continue
 
-        if len(selected_anime.availableScrapers) > 1:
+        if len(selected_item.anime.availableScrapers) > 1:
             if not always_yes:
                 results = interactiveTable(
-                    items=[['',scraperName] for scraperName in selected_anime.availableScrapers],
-                    header=['',t('Escolha uma fonte')],
+                    items=[['',scraperName] for scraperName in selected_item.anime.availableScrapers],
+                    header=['',t('Escolha uma fonte')+f" ({selected_item.title})"],
                     alignment='ll',
                     behaviour='single',
                     maxListSize=10,
@@ -383,33 +398,30 @@ def serverTUI(anilistManager:AnilistManager, default_anime_name:str, episodes_ra
                 if results.selectedItem is None:
                     raise Exception(t('Não foi possível selecionar uma fonte'))
 
-                selected_anime.source = results.selectedItem[1]
+                selected_item.anime.source = results.selectedItem[1]
             else:
-                selected_anime.source = selected_anime.availableScrapers[0]
-
-    # TODO -> create a serverManager class that receive a list of SessionItem and serve a m3u file, in a way that every entry point to the server who returns the correct link on demand
-
-
-    #     sessionmanager.add([anime])
-    #
-    # # sessionmanager.update(anime, results['lastEpisode'], results['watchTime'], results['duration'])
-    #
-    # try:
-    #     anilistManager.merge_session(sessionmanager)
-    # except MissingToken:
-    #     if not config.silent:
-    #         warning("wasn't possible sync with anilist. Missing authentification token")
-    #         warning("to get rid of this message, mark the option 'silent' to True in the config")
-    #         warning("    eg: anime --config")
-    #
-    # print(t('Atualizando o histórico...'))
-    # # anilistManager.update_session(sessionmanager, True)
-    # sessionmanager.dump(verbose=True, number_to_update=10)
-    #
-    # anime_session_item = sessionmanager.find(anime)
-    #
-    # if anime_session_item:
-    #     anilistManager.set_watching([anime_session_item])
+                selected_item.anime.source = selected_item.anime.availableScrapers[0]
 
+            selected_item.lastSource = selected_item.anime.source
+
+    server_manager = ServerManager(selected_items)
+
+    new_items = server_manager.serve()
+
+    sessionmanager.add_session_items(new_items)
+
+    try:
+        anilistManager.merge_session(sessionmanager)
+    except MissingToken:
+        if not config.silent:
+            warning("wasn't possible sync with anilist. Missing authentification token")
+            warning("to get rid of this message, mark the option 'silent' to True in the config")
+            warning("    eg: anime --config")
+
+    print(t('Atualizando o histórico...'))
+    anilistManager.update_session(sessionmanager, True)
+    sessionmanager.dump(verbose=True, number_to_update=10)
+
+    anilistManager.set_watching(new_items)
 
 
