@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 from typing import List,Tuple,Set,Dict
 from lxml.etree import iselement
+from goyabucli.utils import headers
 
 class VideoUrl():
     def __init__(self, url:str, quality:str, lang:str, source:str, scrapers:List['Scraper']=[], ready=False):
@@ -9,6 +10,7 @@ class VideoUrl():
         self.source = source
         self.ready = ready
         self.lang = lang
+        self.headers = headers
         self.quality = quality # sd,hd,full-hd,ultra-hd
 
     def getLink(self) -> List['VideoUrl']:
@@ -58,23 +60,25 @@ class Episode():
         return videoUrls
 
     def retrieveLinks(self, scraperName:str):
-        right_scraper = next((source[1] for source in self.sources if source[0] == scraperName),None)
+        links = next((source[1] for source in self.sources if source[0] == scraperName),None)
 
         if not self.scrapers:
             raise LookupError(f"Cannot access scrapers in episode {self.title}")
 
-        if right_scraper == None:
+        if links == None:
             raise LookupError(f"Cannot find matching source for '{scraperName}' in episode {self.title}")
 
         found_links = []
-        for source in right_scraper:
+        for source in links:
+            if source.ready:
+                continue
             found_links.extend(source.getLink())
 
-        right_scraper.extend(found_links)
+        links.extend(found_links)
 
-        for source in right_scraper.copy():
+        for source in links.copy():
             if not source.ready or not source.test():
-                right_scraper.remove(source)
+                links.remove(source)
 
 
 
